@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019, Brandon Nielsen
+# Copyright (c) 2021, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -14,3 +14,9 @@ if PY2:
     range = xrange
 else:
     range = range
+
+def is_string(tocheck):
+    if PY2:
+        return isinstance(tocheck, str) or isinstance(tocheck, unicode)
+
+    return isinstance(tocheck, str)
