@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019, Brandon Nielsen
+# Copyright (c) 2021, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -21,6 +21,13 @@ def parse_duration(isodurationstr, builder=PythonTimeBuilder):
     #PnYnMnDTnHnMnS (or any reduced precision equivalent)
     #P<date>T<time>
 
+    if compat.is_string(isodurationstr) is False:
+        raise ValueError('Duration must be string.')
+
+    if len(isodurationstr) == 0:
+        raise ISOFormatError('"{0}" is not a valid ISO 8601 duration.'
+                .format(isodurationstr))
+
     if isodurationstr[0] != 'P':
         raise ISOFormatError('ISO 8601 duration must start with a P.')
 
