@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019, Brandon Nielsen
+# Copyright (c) 2021, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -269,6 +269,28 @@ class TestIntervalParserFunctions(unittest.TestCase):
         self.assertEqual(result, expectedargs)
         mockBuilder.build_interval.assert_called_once_with(**expectedargs)
 
+    def test_parse_interval_badtype(self):
+        testtuples = (None, 1, False, 1.234)
+
+        for testtuple in testtuples:
+            with self.assertRaises(ValueError):
+                parse_interval(testtuple, builder=None)
+
+    def test_parse_interval_baddelimiter(self):
+        testtuples = ('1980-03-05T01:01:00,1981-04-05T01:01:00',
+                      'P1M 1981-04-05T01:01:00')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_interval(testtuple, builder=None)
+
+    def test_parse_interval_badstr(self):
+        testtuples = ('bad', '')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_interval(testtuple, builder=None)
+
     def test_parse_interval_repeating(self):
         #Parse interval can't parse repeating intervals
         with self.assertRaises(ISOFormatError):
@@ -283,16 +305,16 @@ class TestIntervalParserFunctions(unittest.TestCase):
     def test_parse_interval_suffixgarbage(self):
         #Don't allow garbage after the duration
         #https://bitbucket.org/nielsenb/aniso8601/issues/9/durations-with-trailing-garbage-are-parsed
-        with self.assertRaises(ValueError):
+        with self.assertRaises(ISOFormatError):
             parse_interval('2001/P1Dasdf', builder=None)
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(ISOFormatError):
             parse_interval('P1Dasdf/2001', builder=None)
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(ISOFormatError):
             parse_interval('2001/P0003-06-04T12:30:05.5asdfasdf', builder=None)
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(ISOFormatError):
             parse_interval('P0003-06-04T12:30:05.5asdfasdf/2001', builder=None)
 
 class TestRepeatingIntervalParserFunctions(unittest.TestCase):
@@ -458,6 +480,20 @@ class TestRepeatingIntervalParserFunctions(unittest.TestCase):
         self.assertEqual(result, args)
         mockBuilder.build_repeating_interval.assert_called_once_with(**args)
 
+    def test_parse_repeating_interval_badtype(self):
+        testtuples = (None, 1, False, 1.234)
+
+        for testtuple in testtuples:
+            with self.assertRaises(ValueError):
+                parse_repeating_interval(testtuple, builder=None)
+
+    def test_parse_repeating_interval_baddelimiter(self):
+        testtuples = ('R,PT1H2M,1980-03-05T01:01:00', 'R3 1981-04-05 P1D')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_repeating_interval(testtuple, builder=None)
+
     def test_parse_repeating_interval_suffixgarbage(self):
         #Don't allow garbage after the duration
         #https://bitbucket.org/nielsenb/aniso8601/issues/9/durations-with-trailing-garbage-are-parsed
@@ -470,6 +506,13 @@ class TestRepeatingIntervalParserFunctions(unittest.TestCase):
                                      'P0003-06-04T12:30:05.5asdfasdf',
                                      builder=None)
 
+    def test_parse_repeating_interval_badstr(self):
+        testtuples = ('bad', '')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_repeating_interval(testtuple, builder=None)
+
     def test_parse_interval_internal(self):
         #Test the internal _parse_interval function
         testtuples = (('P1M/1981-04-05T01:01:00',
