@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019, Brandon Nielsen
+# Copyright (c) 2021, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -9,13 +9,14 @@
 import unittest
 import aniso8601
 
+from aniso8601.exceptions import ISOFormatError
 from aniso8601.resolution import TimeResolution
 from aniso8601.time import (get_time_resolution, parse_datetime, parse_time,
                             _parse_hour, _parse_minute_time,
                             _parse_second_time, _split_tz)
 from aniso8601.tests.compat import mock
 
-class TestTimeParserFunctions(unittest.TestCase):
+class TestTimeResolutionFunctions(unittest.TestCase):
     def test_get_time_resolution(self):
         self.assertEqual(get_time_resolution('01:23:45'),
                          TimeResolution.Seconds)
@@ -66,6 +67,21 @@ class TestTimeParserFunctions(unittest.TestCase):
         self.assertEqual(get_time_resolution('06:14:00.000123Z'),
                          TimeResolution.Seconds)
 
+    def test_get_time_resolution_badtype(self):
+        testtuples = (None, 1, False, 1.234)
+
+        for testtuple in testtuples:
+            with self.assertRaises(ValueError):
+                get_time_resolution(testtuple)
+
+    def test_get_time_resolution_badstr(self):
+        testtuples = ('A6:14:00.000123Z', '06:14:0B', 'bad', '')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                get_time_resolution(testtuple)
+
+class TestTimeParserFunctions(unittest.TestCase):
     def test_parse_time(self):
         testtuples = (('01:23:45', {'hh': '01', 'mm': '23',
                                     'ss': '45', 'tz': None}),
@@ -191,6 +207,20 @@ class TestTimeParserFunctions(unittest.TestCase):
                 self.assertEqual(result, testtuple[1])
                 mockBuildTime.assert_called_once_with(**testtuple[1])
 
+    def test_parse_time_badtype(self):
+        testtuples = (None, 1, False, 1.234)
+
+        for testtuple in testtuples:
+            with self.assertRaises(ValueError):
+                parse_time(testtuple, builder=None)
+
+    def test_parse_time_badstr(self):
+        testtuples = ('A6:14:00.000123Z', '06:14:0B', 'bad', '')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_time(testtuple, builder=None)
+
     def test_parse_time_mockbuilder(self):
         mockBuilder = mock.Mock()
 
@@ -302,6 +332,34 @@ class TestTimeParserFunctions(unittest.TestCase):
         self.assertEqual(result, expectedargs)
         mockBuildDateTime.assert_called_once_with(*expectedargs)
 
+    def test_parse_datetime_baddelimiter(self):
+        testtuples = ('1981-04-05,23:21:28,512400Z',
+                      '2004-W53-6 23:21:28.512400-12:3',
+                      '1981040523:21:28')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_datetime(testtuple, builder=None)
+
+    def test_parse_datetime_badtype(self):
+        testtuples = (None, 1, False, 1.234)
+
+        for testtuple in testtuples:
+            with self.assertRaises(ValueError):
+                parse_datetime(testtuple, builder=None)
+
+    def test_parse_datetime_badstr(self):
+        testtuples = ('1981-04-05TA6:14:00.000123Z',
+                      '2004-W53-6T06:14:0B',
+                      '2014-01-230T23:21:28+00',
+                      '201401230T01:03:11.858714',
+                      'bad',
+                      '')
+
+        for testtuple in testtuples:
+            with self.assertRaises(ISOFormatError):
+                parse_time(testtuple, builder=None)
+
     def test_parse_datetime_mockbuilder(self):
         mockBuilder = mock.Mock()
 
