@@ -1,16 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019, Brandon Nielsen
+# Copyright (c) 2021, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
 # of the BSD license.  See the LICENSE file for details.
 
-from aniso8601.builder import PythonTimeBuilder
+from aniso8601.builders.python import PythonTimeBuilder
+from aniso8601.compat import is_string
 from aniso8601.exceptions import ISOFormatError
 
 def parse_timezone(tzstr, builder=PythonTimeBuilder):
     #tzstr can be Z, ±hh:mm, ±hhmm, ±hh
+    if is_string(tzstr) is False:
+        raise ValueError('Time zone must be string.')
+
     if 'Z' in tzstr:
         if len(tzstr) != 1:
             raise ISOFormatError('"{0}" is not a valid ISO 8601 time offset.'
